@@ -11,7 +11,7 @@ use crate::Rule;
 /// [the angular convention](https://github.com/angular/angular/blob/22b96b9/CONTRIBUTING.md#-commit-message-guidelines)
 /// as their own enum variant. Other type will be parser as [`CommitType::Custom`]
 #[derive(Hash, Eq, PartialEq, Ord, PartialOrd, Debug, Clone)]
-pub enum CommitType<'a> {
+pub enum CommitType {
     /// *feat*: a commit of the type `feat` introduces a new feature to the codebase (this correlates with `MINOR` in Semantic Versioning).
     Feature,
     /// *fix*: a commit of the type `fix` patches a bug in your codebase (this correlates with `PATCH` in Semantic Versioning).
@@ -35,33 +35,33 @@ pub enum CommitType<'a> {
     /// *ci*: Changes to our CI configuration files and scripts (example scopes: Travis, Circle, BrowserStack, SauceLabs)
     Ci,
     /// A custom commit type, can be anything
-    Custom(&'a str),
+    Custom(String),
 }
 
 /// One or more footers MAY be provided one blank line after the body. Each footer MUST consist of
 /// a word token, followed by either a :<space> or <space># separator, followed by a string value.
 #[derive(Debug, Eq, PartialEq, Default, Clone)]
-pub struct Footer<'a> {
+pub struct Footer {
     /// The footer token, either BREAKING CHANGE or a work token
-    pub token: &'a str,
+    pub token: String,
     /// A string value holding the footer message
-    pub content: &'a str,
+    pub content: String,
 }
 
-impl<'a> Footer<'a> {
+impl Footer {
     /// Return true if a footer as the breaking change token
     /// ```rust
     /// # fn main() {
     /// use conventional_commit_parser::commit::Footer;
     /// use std::ops::Not;
     /// let footer = Footer {
-    ///     token: "BREAKING CHANGE", content: "some changes were made",
+    ///     token: "BREAKING CHANGE".to_string(),content: "some changes were made".to_string(),
     /// };
     ///
     /// assert!(footer.is_breaking_change());
     ///
     /// let footer = Footer {
-    ///     token: "a-token", content: "Ref 133",
+    ///     token: "a-token".to_string(),content: "Ref 133".to_string(),
     /// };
     ///
     /// assert!(footer.is_breaking_change().not());
@@ -75,82 +75,47 @@ impl<'a> Footer<'a> {
 ///
 /// [parse]: crate::ConventionalCommitParser::parse
 #[derive(Debug, Eq, PartialEq, Clone)]
-pub struct ConventionalCommit<'a> {
+pub struct ConventionalCommit {
     /// The commit type, `fix`, `feat` etc.
-    pub commit_type: CommitType<'a>,
+    pub commit_type: CommitType,
     /// An optional scope
-    pub scope: Option<&'a str>,
+    pub scope: Option<String>,
     /// Commit description summary
-    pub summary: &'a str,
+    pub summary: String,
     /// An optional commit body
-    pub body: Option<&'a str>,
+    pub body: Option<String>,
     /// A list of commit  footers
-    pub footers: Vec<Footer<'a>>,
+    pub footers: Vec<Footer>,
     /// A commit that has a footer `BREAKING CHANGE` or a `!` after the commit type and scope
     pub is_breaking_change: bool,
 }
 
-impl<'a> ConventionalCommit<'a> {
-    /// Return the breaking change token value if the commit contains a braking change token.
-    /// Returns the commit summary if the breaking change is indicated by an exclamation mark.
-    /// Otherwise None
-    /// ```rust
-    /// # fn main() {
-    /// use conventional_commit_parser::parse;
-    ///
-    /// let  commit = parse("feat!: something broke").unwrap();
-    ///
-    /// assert_eq!(commit.breaking_change_description(), Some("something broke"));
-    ///
-    /// let  commit = parse(r#"feat!: something broke
-    ///
-    /// BREAKING CHANGE #something broke"#).unwrap();
-    ///
-    /// assert_eq!(commit.breaking_change_description(), Some("something broke"));
-    ///
-    /// let  commit = parse("feat: a normal commit").unwrap();
-    ///
-    /// assert_eq!(commit.breaking_change_description(), None);
-    /// # }
-    pub fn breaking_change_description(&self) -> Option<&'a str> {
-        if self.is_breaking_change {
-            self.footers
-                .iter()
-                .find(|footer| footer.is_breaking_change())
-                .map(|footer| footer.content)
-                .or(Some(self.summary))
-        } else {
-            None
-        }
-    }
-}
-
-impl<'a> From<Pair<'a, Rule>> for Footer<'a> {
-    fn from(pairs: Pair<'a, Rule>) -> Self {
+impl From<Pair<'_, Rule>> for Footer {
+    fn from(pairs: Pair<'_, Rule>) -> Self {
         let mut pair = pairs.into_inner();
-        let token = pair.next().unwrap().as_str();
+        let token = pair.next().unwrap().as_str().to_string();
         let _separator = pair.next().unwrap();
-        let content = pair.next().unwrap().as_str();
+        let content = pair.next().unwrap().as_str().to_string();
 
         Footer { token, content }
     }
 }
 
-impl Default for ConventionalCommit<'_> {
+impl Default for ConventionalCommit {
     fn default() -> Self {
         ConventionalCommit {
             commit_type: Feature,
             scope: None,
             body: None,
             footers: vec![],
-            summary: "",
+            summary: "".to_string(),
             is_breaking_change: false,
         }
     }
 }
 
-impl<'a> ConventionalCommit<'a> {
-    pub(crate) fn set_summary(&mut self, pair: Pair<'a, Rule>) {
+impl ConventionalCommit {
+    pub(crate) fn set_summary(&mut self, pair: Pair<Rule>) {
         for pair in pair.into_inner() {
             match pair.as_rule() {
                 Rule::commit_type => self.set_commit_type(&pair),
@@ -168,40 +133,40 @@ impl<'a> ConventionalCommit<'a> {
         }
     }
 
-    fn set_summary_content(&mut self, pair: Pair<'a, Rule>) {
+    fn set_summary_content(&mut self, pair: Pair<Rule>) {
         let summary = pair.as_str();
-        self.summary = summary;
+        self.summary = summary.to_string();
     }
 
-    fn set_scope(&mut self, pair: Pair<'a, Rule>) {
+    fn set_scope(&mut self, pair: Pair<Rule>) {
         if let Some(scope) = pair.into_inner().next() {
             let scope = scope.as_str();
             if !scope.is_empty() {
-                self.scope = Some(scope)
+                self.scope = Some(scope.to_string())
             }
         };
     }
 
-    fn set_commit_type(&mut self, pair: &Pair<'a, Rule>) {
+    pub fn set_commit_type(&mut self, pair: &Pair<Rule>) {
         let commit_type = pair.as_str();
         let commit_type = CommitType::from(commit_type);
         self.commit_type = commit_type;
     }
 
-    pub(crate) fn set_commit_body(&mut self, pair: Pair<'a, Rule>) {
+    pub(crate) fn set_commit_body(&mut self, pair: Pair<Rule>) {
         let body = pair.as_str();
         if !body.is_empty() {
-            self.body = Some(body)
+            self.body = Some(body.to_string())
         }
     }
 
-    pub(crate) fn set_footers(&mut self, pair: Pair<'a, Rule>) {
+    pub(crate) fn set_footers(&mut self, pair: Pair<Rule>) {
         for footer in pair.into_inner() {
             self.set_footer(footer);
         }
     }
 
-    fn set_footer(&mut self, footer: Pair<'a, Rule>) {
+    fn set_footer(&mut self, footer: Pair<Rule>) {
         let footer = Footer::from(footer);
 
         if footer.is_breaking_change() {
@@ -212,8 +177,8 @@ impl<'a> ConventionalCommit<'a> {
     }
 }
 
-impl<'a> From<&'a str> for CommitType<'a> {
-    fn from(commit_type: &'a str) -> Self {
+impl From<&str> for CommitType {
+    fn from(commit_type: &str) -> Self {
         match commit_type.to_ascii_lowercase().as_str() {
             "feat" => Feature,
             "fix" => BugFix,
@@ -226,18 +191,18 @@ impl<'a> From<&'a str> for CommitType<'a> {
             "test" => Test,
             "build" => Build,
             "ci" => Ci,
-            _ => Custom(commit_type),
+            other => Custom(other.to_string()),
         }
     }
 }
 
-impl Default for CommitType<'_> {
+impl Default for CommitType {
     fn default() -> Self {
         CommitType::Chore
     }
 }
 
-impl<'a> AsRef<str> for CommitType<'a> {
+impl AsRef<str> for CommitType {
     fn as_ref(&self) -> &str {
         match self {
             Feature => "feat",
@@ -256,7 +221,7 @@ impl<'a> AsRef<str> for CommitType<'a> {
     }
 }
 
-impl ToString for ConventionalCommit<'_> {
+impl ToString for ConventionalCommit {
     fn to_string(&self) -> String {
         let mut message = String::new();
         message.push_str(self.commit_type.as_ref());
@@ -289,7 +254,7 @@ impl ToString for ConventionalCommit<'_> {
     }
 }
 
-impl fmt::Display for CommitType<'_> {
+impl fmt::Display for CommitType {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         write!(f, "{}", self.as_ref())
     }
@@ -309,18 +274,17 @@ mod test {
         let commit = ConventionalCommit {
             commit_type: CommitType::Feature,
             scope: None,
-            summary: "a feature",
+            summary: "a feature".to_string(),
             body: None,
             footers: Vec::with_capacity(0),
             is_breaking_change: false,
         };
 
-        let expected = "feat: a feature";
-        let commit_str = commit.to_string();
+        let expected = "feat: a feature".to_string();
 
-        assert_that!(commit_str.to_string()).is_equal_to(expected.to_string());
-        let parsed = parse(&commit_str);
-        assert_that!(parsed).is_ok().is_equal_to(commit);
+        assert_that(&commit.to_string()).is_equal_to(expected);
+        let parsed = parse(&commit.to_string());
+        assert_that(&parsed).is_ok().is_equal_to(commit);
     }
 
     #[test]
@@ -328,11 +292,11 @@ mod test {
         let commit = ConventionalCommit {
             commit_type: CommitType::Chore,
             scope: None,
-            summary: "a commit",
+            summary: "a commit".to_string(),
             body: None,
             footers: vec![Footer {
-                token: "BREAKING CHANGE",
-                content: "message",
+                token: "BREAKING CHANGE".to_string(),
+                content: "message".to_string(),
             }],
             is_breaking_change: true,
         };
@@ -341,13 +305,12 @@ mod test {
             "chore: a commit
 
         BREAKING CHANGE: message"
-        );
+        )
+        .to_string();
 
-        let commit_str = commit.to_string();
-
-        assert_that!(commit_str.to_string()).is_equal_to(expected.to_string());
-        let parsed = parse(&commit_str);
-        assert_that!(parsed).is_ok().is_equal_to(commit);
+        assert_that(&commit.to_string()).is_equal_to(expected);
+        let parsed = parse(&commit.to_string());
+        assert_that(&parsed).is_ok().is_equal_to(commit);
     }
 
     #[test]
@@ -355,8 +318,8 @@ mod test {
         let commit = ConventionalCommit {
             commit_type: CommitType::Chore,
             scope: None,
-            summary: "a commit",
-            body: Some("A breaking change body on\nmultiple lines"),
+            summary: "a commit".to_string(),
+            body: Some("A breaking change body on\nmultiple lines".to_string()),
             footers: Vec::with_capacity(0),
             is_breaking_change: true,
         };
@@ -366,34 +329,36 @@ mod test {
 
             A breaking change body on
             multiple lines"
-        );
+        )
+        .to_string();
 
-        let commit_str = commit.to_string();
-
-        assert_that!(commit_str.to_string()).is_equal_to(expected.to_string());
-        let parsed = parse(&commit_str);
-        assert_that!(parsed).is_ok().is_equal_to(commit);
+        assert_that(&commit.to_string()).is_equal_to(expected);
+        let parsed = parse(&commit.to_string());
+        assert_that(&parsed).is_ok().is_equal_to(commit);
     }
 
     #[test]
     fn full_commit_to_string() {
         let commit = ConventionalCommit {
             commit_type: CommitType::BugFix,
-            scope: Some("code"),
-            summary: "correct minor typos in code",
-            body: Some(indoc!(
-                "see the issue for details
+            scope: Some("code".to_string()),
+            summary: "correct minor typos in code".to_string(),
+            body: Some(
+                indoc!(
+                    "see the issue for details
 
         on typos fixed."
-            )),
+                )
+                .to_string(),
+            ),
             footers: vec![
                 Footer {
-                    token: "Reviewed-by",
-                    content: "Z",
+                    token: "Reviewed-by".to_string(),
+                    content: "Z".to_string(),
                 },
                 Footer {
-                    token: "Refs",
-                    content: "133",
+                    token: "Refs".to_string(),
+                    content: "133".to_string(),
                 },
             ],
             is_breaking_change: false,
@@ -408,12 +373,12 @@ mod test {
 
         Reviewed-by: Z
         Refs: 133"
-        );
+        )
+        .to_string();
 
-        let commit_str = commit.to_string();
+        assert_that(&commit.to_string()).is_equal_to(expected);
+        let parsed = parse(&commit.to_string());
 
-        assert_that!(commit_str.to_string()).is_equal_to(expected.to_string());
-        let parsed = parse(&commit_str);
-        assert_that!(parsed).is_ok().is_equal_to(commit);
+        assert_that(&parsed).is_ok().is_equal_to(commit);
     }
 }
