@@ -19,17 +19,17 @@
 //! Reviewed-by: Z
 //! Refs #133"#;
 //!
-//! let commit = parse(message)?;
+//! let conventional_commit = parse(message)?;
 //!
-//! assert_eq!(commit.commit_type, CommitType::BugFix);
-//! assert_eq!(commit.summary, "correct minor typos in code");
-//! assert_eq!(commit.body, Some(r#"see the issue for details
+//! assert_eq!(conventional_commit.commit_type, CommitType::BugFix);
+//! assert_eq!(conventional_commit.summary, "correct minor typos in code".to_string());
+//! assert_eq!(conventional_commit.body, Some(r#"see the issue for details
 //!
-//! on typos fixed."#));
+//! on typos fixed."#.to_string()));
 //!
-//! assert_eq!(commit.footers, vec![
-//!     Footer {token: "Reviewed-by", content: "Z"},
-//!     Footer {token: "Refs", content: "133",}
+//! assert_eq!(conventional_commit.footers, vec![
+//!     Footer {token: "Reviewed-by".to_string(), content: "Z".to_string()},
+//!     Footer {token: "Refs".to_string(), content: "133".to_string(),}
 //! ]);
 //!
 //! # Ok(())
@@ -48,7 +48,7 @@ use pest::Parser;
 use crate::commit::{ConventionalCommit, Footer};
 use crate::error::ParseError;
 
-/// Conventional commit representation, produced by the [`parse`] function
+/// Conventional commit representation, produced by the [parse] function
 ///
 /// [parse]: crate::ConventionalCommitParser::parse
 pub mod commit;
@@ -98,8 +98,8 @@ pub fn parse(commit_message: &str) -> Result<ConventionalCommit, ParseError> {
 ///
 /// assert_eq!(parsed, ConventionalCommit {
 ///     commit_type: CommitType::Feature,
-///     scope: Some("parser"),
-///     summary: "implement parse_summary",
+///     scope: Some("parser".to_string()),
+///     summary: "implement parse_summary".to_string(),
 ///     body: None,
 ///     footers: vec![],
 ///     is_breaking_change: false
@@ -133,10 +133,10 @@ pub fn parse_summary(summary: &str) -> Result<ConventionalCommit, ParseError> {
 ///
 /// let parsed = parse_body(body).expect("Parse error");
 ///
-/// assert_eq!(parsed, Some(body));
+/// assert_eq!(parsed, Some(body.to_string()));
 /// # Ok(())
 /// # }
-pub fn parse_body(body: &str) -> Result<Option<&str>, ParseError> {
+pub fn parse_body(body: &str) -> Result<Option<String>, ParseError> {
     let pair = ConventionalCommitParser::parse(Rule::body, body)
         .map_err(ParseError::from)?
         .next()
@@ -144,7 +144,7 @@ pub fn parse_body(body: &str) -> Result<Option<&str>, ParseError> {
 
     let body = pair.as_str();
     if !body.is_empty() {
-        Ok(Some(body))
+        Ok(Some(body.to_string()))
     } else {
         Ok(None)
     }
@@ -166,8 +166,8 @@ pub fn parse_body(body: &str) -> Result<Option<&str>, ParseError> {
 /// let parsed = parse_footers(footer).expect("Parse error");
 ///
 /// assert_eq!(parsed, vec![
-///     Footer { token: "a-token", content: "this is a token" },
-///     Footer { token: "another-token", content: "this is a token with hash separator" }
+///     Footer { token: "a-token".to_string(), content: "this is a token".to_string() },
+///     Footer { token: "another-token".to_string(), content: "this is a token with hash separator".to_string() }
 /// ]);
 /// # Ok(())
 /// # }
